@@ -6,4 +6,4 @@
 import pkg_resources
 __version__ = pkg_resources.require("wunderpy")[0].version
 
-from .wunderlist import Wunderlist
+from wunderpy.wunderlist import Wunderlist
